(function($){
  'use strict';

  // Remove background videos on mobile devices
  if ($.browser.mobile) {
    $('video').remove();

    $('[data-mobile-style]').each(function(){
      var $el = $(this),
          style = $el.attr('data-mobile-style');

      if (typeof style !== 'undefined') {
        $el.attr('style', style);
      }
    });
  }

  if (!Modernizr.video) {
    $('video').remove();
  }


  function verticalCenter(context) {
    if (!Modernizr.csstransforms) {
      var $body = $('body');
      context = context || $body;

      $('.js-vertical-center', context).each(function(){
        var $el = $(this),
            breakpoint = $(this).attr('data-vertical-center-breakpoint') || null;

        if (breakpoint === 'small') {
          if ($body.width() > 768) {
            $el.css('marginTop', -($el.outerHeight() / 2));
          }
        } else {
          $el.css('marginTop', -($el.outerHeight() / 2));
        }
      });
    }
  }

  verticalCenter();

  // Get Youtube Iframe API async
  $.getScript('https://www.youtube.com/iframe_api');
  var youtubePlayers = {};

  function pauseVideos(skipId) {
    $.each(youtubePlayers, function(id, video){
      if (skipId !== id) {
        video.pauseVideo();
      }
    });

    if (Modernizr.video) {
      $('video').each(function(){
        $(this).get(0).pause();
      });
    }
  }

  function resumeVideo(video) {
    if (Modernizr.video) {
      if (video.length > 0) {
        video.get(0).play();
      }
    }
  }

  $('[data-toggle]').each(function(){
    var $that = $(this),
        $toggleEl = $('#' + $that.attr('data-toggle')),
        toggleType = $that.attr('data-toggle-type') || 'fade',
        $video = $('video', $toggleEl);
        $toggleEl.addClass('kw_opacity_null');

    $that.on('click', function(ev) {
      ev.preventDefault();
      $('.is-active').removeClass('is-active');
      $('.kw-overlay--video').fadeOut();
      $('.kw-frame').fadeIn(500);


      if (toggleType == 'opacity') {
        if ($toggleEl.css('opacity') == 1) {
          var opacityVal = 0;
        } else {
          var opacityVal = 1;
        }

        $toggleEl.animate({
          opacity: opacityVal
        }, 500);
      } else if (toggleType == 'fade') {
        if ($toggleEl.hasClass('kw_opacity_null')) {
          $('.js-toggle').addClass('kw_opacity_null');
          $that.addClass('is-active');
          $toggleEl.addClass('js-toggle');
          $toggleEl.removeClass('kw_opacity_null');
          verticalCenter($toggleEl);
          pauseVideos();

          if ($video.length > 0) {
            $video.get(0).play();
          }
        } else {
          $toggleEl.removeClass('js-toggle');
          $toggleEl.addClass('kw_opacity_null');
          resumeVideo($('#kw-hero-video'));

          if ($video.length > 0) {
            $video.get(0).pause();
          }
        }
      } 

    });
  });





  $('[data-video]').each(function(){
    var $that = $(this),
        $videoEl = $('#' + $that.attr('data-video')),
        $bgVideoEl = $('#' + $that.attr('data-video-bg')),
        $ytVideo = $('[data-youtube]', $videoEl),
        ytVideoId = $ytVideo.attr('data-youtube'),
        ytVideoElId = $ytVideo.attr('id');

    $that.on('click', function(ev) {
      ev.preventDefault();
      pauseVideos();

      if ($videoEl.is(':hidden')) {
        $videoEl.fadeIn(500);
        $('.kw-frame').fadeOut(500);

        if (!(ytVideoElId in youtubePlayers)) {
          youtubePlayers[ytVideoElId] = new YT.Player(ytVideoElId, {
            playerVars: { 'autoplay': 1, 'rel': 0 },
            height: '390',
            width: '640',
            videoId: ytVideoId,
            events: {
              'onStateChange': function(event) {
                if (event.data === YT.PlayerState.PLAYING) {
                  pauseVideos(ytVideoElId);
                }
              }
            }
          });
        }
      } else {
        $videoEl.fadeOut(500);
        $('.kw-frame').fadeIn(500);
        resumeVideo($bgVideoEl);
      }
    });
  });



  // Lines animation

  $(document).ready(function () {

    var $item = $('article.kw-video');
    var $linkd = $('.kw-box--link');
    var $line = $('.kw_line');

    $linkd.click(function(){
      var tab_id = $(this).attr('data-toggle');
      var complete = $(this).hasClass('kw_current');

      if (complete === true) {

        $line.removeClass('kw_line_anim');  

      } else {

        $line.removeClass('kw_line_anim');

        $('#'+tab_id+' .kw_line').addClass('kw_line_anim');
      };
    })

  });


  // Fluids anchors

  $('a[href^="#"]').click(function(){  
    var id = $(this).attr("href");
    var offset = $(id).offset().top 
    $('html, body').animate({scrollTop: offset}, 'slow'); 
    return false;  
  }); 

  $('[data-anchor-bottom]').click(function(){  
    var offsett = $('#kw_second_part').offset().top
    $('html, body').animate({scrollTop: offsett}, 'slow');  
  }); 

   




})(jQuery);
